@@ -562,9 +562,11 @@ def irls_solver(
                 beta_init,
                 jac=df,
                 method=optimizer,
-                bounds=[(min_beta, max_beta)] * num_vars
-                if optimizer == "L-BFGS-B"
-                else None,
+                bounds=(
+                    [(min_beta, max_beta)] * num_vars
+                    if optimizer == "L-BFGS-B"
+                    else None
+                ),
             )
 
             beta = res.x
@@ -710,9 +712,9 @@ def fit_alpha_mle(
         x0=np.log(alpha_hat),
         jac=lambda x: dloss(x[0]),
         method=optimizer,
-        bounds=[(np.log(min_disp), np.log(max_disp))]
-        if optimizer == "L-BFGS-B"
-        else None,
+        bounds=(
+            [(np.log(min_disp), np.log(max_disp))] if optimizer == "L-BFGS-B" else None
+        ),
     )
 
     if res.success:
@@ -1588,7 +1590,10 @@ def lowess(
 
         residuals = targets - yest
         s = np.median(np.abs(residuals))
-        delta = np.clip(residuals / (6.0 * s), -1, 1)
+        if s == 0:
+            delta = (np.abs(residuals) > 0).astype(float)
+        else:
+            delta = np.clip(residuals / (6.0 * s), -1, 1)
         delta = (1 - delta**2) ** 2
 
     return yest
