@@ -35,21 +35,30 @@ def metadata():
     )
 
 
-def test_deseq(counts_df, metadata, tol=0.02):
+@pytest.mark.parametrize("independendent_filtering", [True, False])
+def test_deseq(counts_df, metadata, independendent_filtering, tol=0.02):
     """Test that the outputs of the DESeq2 function match those of the original R
     package, up to a tolerance in relative error.
     """
 
     test_path = str(Path(os.path.realpath(tests.__file__)).parent.resolve())
 
-    r_res = pd.read_csv(
-        os.path.join(test_path, "data/single_factor/r_test_res.csv"), index_col=0
-    )
+    if independendent_filtering:
+        r_res = pd.read_csv(
+            os.path.join(test_path, "data/single_factor/r_test_res.csv"), index_col=0
+        )
+    else:
+        r_res = pd.read_csv(
+            os.path.join(
+                test_path, "data/single_factor/r_test_res_no_independent_filtering.csv"
+            ),
+            index_col=0,
+        )
 
     dds = DeseqDataSet(counts=counts_df, metadata=metadata, design_factors="condition")
     dds.deseq2()
 
-    res = DeseqStats(dds)
+    res = DeseqStats(dds, independent_filter=independendent_filtering)
     res.summary()
     res_df = res.results_df
 
@@ -109,11 +118,6 @@ def test_alt_hypothesis(alt_hypothesis, counts_df, metadata, tol=0.02):
         abs(r_res.pvalue[r_res.stat != 0] - res_df.pvalue[res_df.stat != 0])
         / r_res.pvalue[r_res.stat != 0]
     ).max() < tol
-    # Not passing
-    # assert (
-    #     abs(r_res.padj[r_res.stat != 0] - res_df.padj[res_df.stat != 0])
-    #     / r_res.padj[r_res.stat != 0]
-    # ).max() < tol
 
 
 def test_deseq_no_refit_cooks(counts_df, metadata, tol=0.02):
@@ -173,7 +177,8 @@ def test_lfc_shrinkage(counts_df, metadata, tol=0.02):
     ).squeeze()
 
     r_dispersions = pd.read_csv(
-        os.path.join(test_path, "data/single_factor/r_test_dispersions.csv"), index_col=0
+        os.path.join(test_path, "data/single_factor/r_test_dispersions.csv"),
+        index_col=0,
     ).squeeze()
 
     dds = DeseqDataSet(counts=counts_df, metadata=metadata, design_factors="condition")
@@ -426,6 +431,50 @@ def test_continuous_lfc_shrinkage(tol=0.02):
     ).max() < tol
 
 
+def test_wide_deseq(
+    tol=0.02,
+):
+    """Test that the outputs of the DESeq2 function match those of the original R
+    package, up to a tolerance in relative error, on a dataset with more genes than
+    samples.
+    """
+
+    test_path = str(Path(os.path.realpath(tests.__file__)).parent.resolve())
+
+    counts_df = pd.read_csv(
+        os.path.join(test_path, "data/wide/test_counts.csv"), index_col=0
+    ).T
+
+    metadata = pd.read_csv(
+        os.path.join(test_path, "data/wide/test_metadata.csv"), index_col=0
+    )
+
+    # Load R results
+    r_res = pd.read_csv(os.path.join(test_path, "data/wide/r_test_res.csv"), index_col=0)
+
+    dds = DeseqDataSet(
+        counts=counts_df,
+        metadata=metadata,
+        design_factors=["group", "condition"],
+    )
+    dds.deseq2()
+
+    res = DeseqStats(dds)
+    res.summary()
+    res_df = res.results_df
+
+    # check that the same p-values are NaN
+    assert (res_df.pvalue.isna() == r_res.pvalue.isna()).all()
+    assert (res_df.padj.isna() == r_res.padj.isna()).all()
+
+    # Check that the same LFC, p-values and adjusted p-values are found (up to tol)
+    assert (
+        abs(r_res.log2FoldChange - res_df.log2FoldChange) / abs(r_res.log2FoldChange)
+    ).max() < tol
+    assert (abs(r_res.pvalue - res_df.pvalue) / r_res.pvalue).max() < tol
+    assert (abs(r_res.padj - res_df.padj) / r_res.padj).max() < tol
+
+
 def test_contrast(counts_df, metadata):
     """
     Check that the contrasts ['condition', 'B', 'A'] and ['condition', 'A', 'B'] give
